import { Component,Input ,ViewChild,ElementRef,ChangeDetectorRef} from '@angular/core';
import { Store } from '@ngrx/store';

import { IListItem  } from '../../models/list.item';
import { commonReducers,ItemTypeService } from '../../../public-api'
import { EditImageModalComponent} from '../edit-image-modal/edit-image-modal.component';
import { AppConfig } from "../../shared/app.config";

@Component({
    selector: 'fm-thumbnail',
    templateUrl: 'thumbnail.component.html',
    styleUrls: ['thumbnail.component.scss']
  })
  
  
  export class ThumbnailComponent {
    @Input() public item: IListItem;
    @Input() public edit: boolean = false;
    @ViewChild('thumbnail') el:ElementRef;
    @ViewChild('modal') modal:EditImageModalComponent;

    constructor(public store: Store<commonReducers.State>, public itemTypeService: ItemTypeService,public appConfig: AppConfig,private changeDetector:ChangeDetectorRef) {
    }

    getThumbnailUrl(item:IListItem):string {
        return this.appConfig.getConfig("apiEndPoint")+item.url+'/thumbnail?v=' + Date.parse(item.updated);
    }

    getFontSize():string {        
        if(this.el) {
            var h = this.el.nativeElement.offsetHeight - (this.el.nativeElement.offsetHeight / 5 )
            return  h + "px";
        } else {
            return "1em";
        }
    }

    getLineHeight():string {
        if(this.el) {
            return  this.el.nativeElement.offsetHeight + "px";
        } else {
            return "1em";
        }
    }

    canEdit():boolean {
        return this.edit && this.item != null;
    }

    onEditClick() {
       var endpoint = `${this.appConfig.getConfig("apiEndPoint")}/api/v1/items/${this.item.code}/thumbnail`;
       this.modal.open(endpoint,4/3);
    }

    onChanged() {
        if(this.item) {
            this.item.updated = new Date(new Date().getTime()).toISOString();
            this.changeDetector.detectChanges();
        }
    }
  }